@@ -8,9 +8,10 @@ import (
 	"github.com/zclconf/go-cty/cty"
 	"github.com/zclconf/go-cty/cty/gocty"
 
-	"github.com/aquasecurity/defsec/parsers/terraform"
-	"github.com/aquasecurity/defsec/providers"
-	"github.com/aquasecurity/defsec/rules"
+	"github.com/aquasecurity/defsec/pkg/providers"
+	"github.com/aquasecurity/defsec/pkg/rules"
+	"github.com/aquasecurity/defsec/pkg/scan"
+	"github.com/aquasecurity/defsec/pkg/terraform"
 )
 
 var matchFunctions = map[CheckAction]func(*terraform.Block, *MatchSpec, *customContext) bool{
@@ -230,7 +231,7 @@ var AttrMatchFunctions = map[CheckAction]func(*terraform.Attribute, *MatchSpec,
 func ProcessFoundChecks(checks ChecksFile) {
 	for _, customCheck := range checks.Checks {
 		func(customCheck Check) {
-			rules.Register(rules.Rule{
+			rules.Register(scan.Rule{
 				Service:    "custom",
 				ShortCode:  customCheck.Code,
 				Summary:    customCheck.Description,
@@ -239,12 +240,12 @@ func ProcessFoundChecks(checks ChecksFile) {
 				Provider:   providers.CustomProvider,
 				Links:      customCheck.RelatedLinks,
 				Severity:   customCheck.Severity,
-				CustomChecks: rules.CustomChecks{
-					Terraform: &rules.TerraformCustomCheck{
+				CustomChecks: scan.CustomChecks{
+					Terraform: &scan.TerraformCustomCheck{
 						RequiredTypes:   customCheck.RequiredTypes,
 						RequiredLabels:  customCheck.RequiredLabels,
 						RequiredSources: customCheck.RequiredSources,
-						Check: func(rootBlock *terraform.Block, module *terraform.Module) (results rules.Results) {
+						Check: func(rootBlock *terraform.Block, module *terraform.Module) (results scan.Results) {
 							matchSpec := customCheck.MatchSpec
 							if !evalMatchSpec(rootBlock, matchSpec, NewCustomContext(module)) {
 								results.Add(
